@@ -8,7 +8,6 @@
 
 import yaml
 import os
-from ETAES.globals.mapItem import MAPPING_CLASS
 
 def build_config(config_path):
     with open(config_path, 'r') as f:
@@ -18,6 +17,9 @@ def build_config(config_path):
 
 def build_paths(task_id, configs):
     path_cfgs = configs['basic']['paths']
+    # mlflow_tracking_path = path_cfgs.pop('mlflow_tracking_path')
+    # if not os.path.exists(mlflow_tracking_path):
+    #     os.mkdir(mlflow_tracking_path)
     for k, v in path_cfgs.items():
         v = v.format(task_id=task_id)
         if not os.path.exists(v):
@@ -30,9 +32,3 @@ def build_paths(task_id, configs):
                     if not os.path.exists(path):
                         os.mkdir(path)
 
-def component_register(func):
-    def wrapper(*args, **kwargs):
-        if "module" in kwargs.keys():
-            MAPPING_CLASS.append(kwargs["module"])
-        return func(*args, **kwargs)
-    return wrapper
