@@ -8,17 +8,20 @@
 import os
 
 import importlib
-from ETAES.globals.mapItem import MAPPING_CLASS, MAPPING_COMPONENTS
+from ETAES.globals.mapItem import build_mapping_classes
 
 def build_mapping(modules):
     mapping_dict = {}
     for module in modules:
-        all = module.__all__
-        for item in all:
-            mapping_dict[item] = getattr(module, item)
+        try:
+            all = module.__all__
+            for item in all:
+                mapping_dict[item] = getattr(module, item)
+        except:
+            pass
     return mapping_dict
 
-def mapping(func_name, mapping_classes = MAPPING_CLASS):
+def mapping(func_name, mapping_classes = build_mapping_classes()):
     mapping_dict = build_mapping(mapping_classes)
     return mapping_dict[func_name]
 
